@@ -112,8 +112,8 @@ class World(Singleton):
         """
         if verbose:
             print("[WORLD] Reigster Agent %s of class %s " % (agent,agent.__class__))
-        
-        if agent.__class__ in self.agent_types:
+
+        if agent.__class__ not in self.agent_types:
             self.agent_types.append(agent.__class__) # append new key if doesnt exist yet
 
         self.agent_registry.insert(agent.__class__.__name__, agent) # write new agent to data structure
